Table

Type Alias Table 

pub type Table = Map<String, Value>;
Type representing a TOML table, payload of the Value::Table variant.

By default it entries are stored in lexicographic order of the keys. Enable the preserve_order feature to store entries in the order they appear in the source file.

Aliased Type

pub struct Table { /* private fields */ }