infer_path

Function infer_path 

pub fn infer_path(method_name: &str, http_method: HttpMethod) -> String
Infer a REST path from a method name and HTTP method.

This is the runtime version used in generated introspection code. It does not have access to parameter information, so it cannot infer /{id} paths contextually. See server_less_parse (or server_less_macros::openapi_gen) for the richer compile-time version that uses parameter names to infer /{id} paths.