pub struct SchemaValidationError {
pub schema_type: String,
pub missing_lines: Vec<String>,
pub extra_lines: Vec<String>,
}Expand description
Error type for schema validation failures.
Used by schema validation methods (validate_schema) in generated code.
Fields
schema_type: StringSchema type (proto, capnp, thrift, smithy, etc.)
missing_lines: Vec<String>Lines present in expected schema but missing from generated
extra_lines: Vec<String>Lines present in generated schema but not in expected
Implementations
Sourceimpl SchemaValidationError
impl SchemaValidationError
Sourcepub fn new(schema_type: impl Into<String>) -> SchemaValidationError
pub fn new(schema_type: impl Into<String>) -> SchemaValidationError
Create a new schema validation error
Sourcepub fn add_missing(&mut self, line: impl Into<String>)
pub fn add_missing(&mut self, line: impl Into<String>)
Add a line that’s missing from the generated schema
Sourcepub fn add_extra(&mut self, line: impl Into<String>)
pub fn add_extra(&mut self, line: impl Into<String>)
Add a line that’s extra in the generated schema
Sourcepub fn has_differences(&self) -> bool
pub fn has_differences(&self) -> bool
Check if there are any differences