Context and parameter extraction types.
Structs
- Context
- Protocol-agnostic request context.
- Json
- Marker type for parameters that should be extracted from request body
- Path
- Marker type for parameters that should be extracted from the URL path
- Query
- Marker type for parameters that should be extracted from query string
- WsSender
- WebSocket sender for server-push messaging.